Welcome to |project| documentation!
===================================

.. include:: ../README.rst 

.. toctree::
   :maxdepth: 1

   history

.. tidelift-referral-banner::

.. automodule:: keyring
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: keyring.backend
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: keyring.core
    :members:
    :undoc-members:
    :show-inheritance:

.. automodule:: keyring.credentials
    :members:
    :undoc-members:
    :show-inheritance:


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

